@@ -1,10 +1,9 @@
 package TestSchema::ResultSet;
-our $VERSION = '2.003002';
 
 use strict;
 use warnings;
 
-use base 'DBIx::Class::ResultSet';
+use parent 'DBIx::Class::ResultSet';
 
 __PACKAGE__->load_components('Helper::ResultSet::IgnoreWantarray');
 
